using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using Vevo.Shared.Domain.SystemServices;

namespace Vevo.Shared.Domain
{
    public class EmailTemplate
    {
        #region Public Constances

        public const string TemplateFolder = "ContentTemplates\\";

        #endregion


        #region Private

        private bool _isValid;

        private string _subject = String.Empty;
        private string _body = String.Empty;


        private static string GetPath( string fileName )
        {
            string path = Path.Combine( "~/", TemplateFolder );
            path = Path.Combine( path, fileName );
            return path;
        }

        #endregion


        #region Constructors

        private EmailTemplate( bool isValid, string subject, string body )
        {
            _isValid = isValid;
            _subject = subject;
            _body = body;
        }

        #endregion


        #region Public Properties

        public bool IsValid { get { return _isValid; } }
        public string Subject { get { return _subject; } }
        public string Body { get { return _body; } }

        #endregion


        #region Public Methods

        public static EmailTemplate LoadTemplate(
            IFileManager fileManager,
            string subjectFileName,
            string bodyFileName )
        {
            bool isValid = true;
            string subject = String.Empty;
            string body = String.Empty;
            try
            {
                if (!String.IsNullOrEmpty( subjectFileName ))
                    subject = fileManager.ReadToEnd( GetPath( subjectFileName ) );

                if (!String.IsNullOrEmpty( bodyFileName ))
                    body = fileManager.ReadToEnd( GetPath( bodyFileName ) );
            }
            catch
            {
                isValid = false;
            }

            return new EmailTemplate( isValid, subject, body );
        }

        #endregion

    }
}
