using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Vevo.Domain;
using Vevo.Domain.Products;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;

namespace Vevo.Data.Implementation
{
    internal class ProductOptionGroupAccess
    {
        #region Private

        private IList<ProductOptionGroup> ConvertProductOptionGroupTableToList( Culture culture, DataTable table )
        {
            IList<ProductOptionGroup> list = new List<ProductOptionGroup>();

            foreach (DataRow row in table.Rows)
            {
                ProductOptionGroup productOptionGroup = new ProductOptionGroup( culture );
                productOptionGroup.OptionGroupID = row["OptionGroupID"].ToString();
                productOptionGroup.UseStock = ConvertUtilities.ToBoolean( row["UseStock"] );

                list.Add( productOptionGroup );
            }

            return list;
        }

        #endregion


        #region Public Methods

        public void SaveAll( string productID, IList<ProductOptionGroup> productOptionGroups )
        {
            DeleteByProductID( productID );
            InsertOptionGroups( productID, productOptionGroups );
        }

        private void InsertOptionGroups( string productID, IList<ProductOptionGroup> productOptionGroups )
        {
            foreach (ProductOptionGroup productOptionGroup in productOptionGroups)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductOptionGroup (ProductID ,OptionGroupID, UseStock ) " +
                    "VALUES ( @ProductID, @OptionGroupID, @UseStock );",
                    DataAccess.CreateParameterString( productID ),
                    DataAccess.CreateParameterString( productOptionGroup.OptionGroupID ),
                    DataAccess.CreateParameterBool( productOptionGroup.UseStock ) );
            }
        }

        public int DeleteByProductID( string productID )
        {
            return DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductOptionGroup " +
                "WHERE ProductID = @ProductID ;",
                DataAccess.CreateParameterString( productID ) );
        }

        public IList<ProductOptionGroup> GetByProductID( Culture culture, string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, OptionGroupID, UseStock " +
                "FROM ProductOptionGroup " +
                "WHERE ProductID = @ProductID; ",
                DataAccess.CreateParameterString( productID ) );

            return ConvertProductOptionGroupTableToList( culture, table );
        }

        #endregion

    }
}
