﻿using System.Collections.Generic;
using System.Data;
using Vevo.Domain.Products;
using Vevo.Shared.DataAccess;
using System;
using System.Collections;

namespace Vevo.Data.Implementation
{
    internal class ProductSpecificationAccess
    {
        #region Private

        private ProductSpecification CreateOneFromRow( DataRow row )
        {
            ProductSpecification productSpecification = new ProductSpecification();
            productSpecification.ProductID = row["ProductID"].ToString();
            productSpecification.SpecificationItemID = row["SpecificationItemID"].ToString();
            productSpecification.Value = row["Value"].ToString();

            return productSpecification;
        }

        private IList<ProductSpecification> ConvertTableToList( DataTable table )
        {
            IList<ProductSpecification> list = new List<ProductSpecification>();
            foreach (DataRow row in table.Rows)
            {
                list.Add( CreateOneFromRow( row ) );
            }

            return list;
        }

        private IList<string> ConvertTableToIDList( DataTable table )
        {
            IList<string> list = new List<string>();
            foreach (DataRow row in table.Rows)
            {
                list.Add( row["SpecificationItemID"].ToString() );
            }

            return list;
        }

        private void InsertProductSpecifications( string productID, IList<ProductSpecification> productSpecifications )
        {
            foreach (ProductSpecification productSpecification in productSpecifications)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO ProductSpecification (ProductID ,SpecificationItemID, Value ) " +
                    "VALUES ( @ProductID, @OptionGroupID, @UseStock );",
                    DataAccess.CreateParameterString( productID ),
                    DataAccess.CreateParameterString( productSpecification.SpecificationItemID ),
                    DataAccess.CreateParameterString( productSpecification.Value ) );
            }
        }

        #endregion

        #region Public

        public IList<ProductSpecification> GetByProductID( string productID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, SpecificationItemID , Value " +
                "FROM ProductSpecification " +
                "WHERE ProductID = @ProductID;",
                DataAccess.CreateParameterString( productID ) );

            return ConvertTableToList( table );
        }

        private string CreateProductIDsQuery( IList<String> productIDs )
        {
            string query = String.Empty;

            for (int i = 0; i <= productIDs.Count - 1; i++)
            {
                query += "ProductID = @ID" + i.ToString();
                if (i < productIDs.Count - 1)
                {
                    query += " or ";
                }
            }
            return query;
        }

        private string CreateSpecificationIDsQuery( IList<String> specIDs )
        {
            string query = String.Empty;

            for (int i = 0; i <= specIDs.Count - 1; i++)
            {
                query += "SpecificationItemID = @ID" + i.ToString();
                if (i < specIDs.Count - 1)
                {
                    query += " or ";
                }
            }
            return query;
        }

        public IList<string> GetSpecificationsIDListByProductIDList( IList<String> productIDs )
        {
            ArrayList parameterList = new ArrayList();
            for (int i = 0; i <= productIDs.Count - 1; i++)
            {
                parameterList.Add( DataAccess.CreateParameterString( productIDs[i] ) );
            }

            DataTable table = DataAccess.ExecuteSelect(
                "SELECT Distinct SpecificationItemID " +
                "FROM ProductSpecification " +
                "WHERE " + CreateProductIDsQuery( productIDs ),
                DataAccess.ConvertArrayListToDbParameters( parameterList ) );

            return ConvertTableToIDList( table );
        }

        public void Delete()
        {
            DataAccess.ExecuteNonQuery( "DELETE FROM ProductSpecification " );
        }

        public void DeleteByProductID( string productID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ProductSpecification " +
                "WHERE ProductID = @ProductID",
                DataAccess.CreateParameterString( productID ) );
        }

        public void SaveAll( string productID, IList<ProductSpecification> productSpecifications )
        {
            DeleteByProductID( productID );
            InsertProductSpecifications( productID, productSpecifications );
        }

        public IList<ProductSpecification> GetAll()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, SpecificationItemID , Value " +
                "FROM ProductSpecification " );
            return ConvertTableToList( table );
        }

        public IList<ProductSpecification> GetAllProductSpecificationValueByItemID( string specificationItemID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT DISTINCT ProductSpecification.ProductID, ProductSpecification.SpecificationItemID, Value " +
                "FROM ProductSpecification " +
                "LEFT JOIN " +
                "(SELECT * FROM SpecificationItem) AS SpecificationItem " +
                "ON ProductSpecification.SpecificationItemID = SpecificationItem.SpecificationItemID " +
                "WHERE ProductSpecification.SpecificationItemID = @SpecificationItemID ;",
                DataAccess.CreateParameterString( specificationItemID ) );

            return ConvertTableToList( table );
        }

        public IList<ProductSpecification> GetAllProductSpecificationValueByItemIDAndValue( string specificationItemID, string specificationItemValue )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT ProductID, SpecificationItemID, Value " +
                "FROM ProductSpecification " +
                "WHERE SpecificationItemID = @SpecificationItemID " +
                "AND Value LIKE '%" + specificationItemValue + "%' ;",
                DataAccess.CreateParameterString( specificationItemID ) );

            return ConvertTableToList( table );
        }

        #endregion

    }
}
