using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using Vevo.Domain.Users;
using Vevo.Domain.Configurations;
using Vevo.Domain.Orders;
using com.paypal.sdk.services;
using com.paypal.sdk.util;
using Vevo.Shared.Domain.SystemServices;
using Vevo.Deluxe.Domain.Orders;

namespace Vevo.Domain.Payments
{
    public class ProcessPaymentService
    {
        #region Private

        private IHttpService _httpService;

        #endregion


        #region Protected

        protected IHttpService HttpService
        {
            get { return _httpService; }
        }


        protected CartItemGroup GetNonRecurringCartItemGroup( Cart cart )
        {
            foreach (CartItemGroup cartItemGroup in cart.SeparateCartItemGroups())
            {
                if (!cartItemGroup.IsRecurring)
                    return cartItemGroup;
            }
            return null;
        }

        protected bool ProcessDirectPayment(
            CheckoutDetails checkout,
            CartItemGroup cartItemGroup,
            Culture culture,
            Currency currency,
            Customer customer,
            string storefrontUrl,
            string ipAddress,
            out PaymentAppResult paymentResult )
        {
            OrderCalculator orderCalculator = new OrderCalculator();
            IList<CartItemGroup> cartItemGroupList = new List<CartItemGroup>();
            cartItemGroupList.Add( cartItemGroup );

            OrderAmount orderAmount = orderCalculator.Calculate( checkout, cartItemGroupList, customer )
                .Add( CartItemPromotion.CalculatePromotionShippingAndTax(
                checkout,
                cartItemGroupList,
                customer) );

            PaymentAppGateway paymentAppGateway = new PaymentAppGateway( checkout );

            string postData = paymentAppGateway.CreateOnWebsitePaymentXml(
                                culture,
                                orderAmount.Total,
                                "",
                                ipAddress,
                                storefrontUrl,
                                true );

            paymentResult = paymentAppGateway.PostCommand( this.HttpService, postData, storefrontUrl );

            if (paymentResult.Status == PaymentAppResult.PaymentStatus.OK)
            {
                return true;
            }
            else
            {
                return false;
            }
        }

        #endregion


        #region Constructors

        public ProcessPaymentService( IHttpService httpService )
        {
            _httpService = httpService;
        }

        #endregion


        #region Public Methods

        public static ProcessPaymentService CreateNew( IHttpService httpService, Cart shoppingCart )
        {
            foreach (CartItemGroup cartItemGroup in shoppingCart.SeparateCartItemGroups())
            {
                if (cartItemGroup.IsRecurring)
                    return new ProcessRecurringPaymentService( httpService );
            }
            return new ProcessPaymentService( httpService );
        }

        public virtual bool ProcessPayPalProUSPayment(
            decimal amount,
            Currency currency,
            Culture culture,
            CheckoutDetails checkout,
            Cart cart,
            Customer customer,
            string storefrontUrl,
            string ipAddress,
            out PaymentAppResult paymentResult,
            out RecurringPaymentResult recurringPaymentResult )
        {
            bool processFlag = true;

            PaymentErrors.Instance.Clear();

            paymentResult = new PaymentAppResult();
            recurringPaymentResult = new RecurringPaymentResult();

            string errorMessage = String.Empty;
            string paymentLog = String.Empty;

            CartItemGroup nonRecurringCartItemGroup = GetNonRecurringCartItemGroup( cart );

            if (amount > 0m)
            {
                processFlag = ProcessDirectPayment(
                    checkout,
                    nonRecurringCartItemGroup,
                    culture,
                    currency,
                    customer,
                    storefrontUrl,
                    ipAddress,
                    out paymentResult );

                errorMessage += paymentResult.ErrorMessage;
                paymentLog += paymentResult.PaymentLog;
            }

            return processFlag;
        }

        #endregion

    }
}
