﻿using System;
using System.Collections.Generic;
using Vevo.Domain.Base;

namespace Vevo.Domain.Blogs
{
    public class BlogCategory :ILocaleLoader, ICloneable
    {
         #region Private

        // Members for properties
        private string _blogCategoryID = "0";
        private string _urlName = String.Empty;
        private bool _isEnabled = true;
        private int _sortOrder = 0;

        private Culture _defaultCulture;
        private LocaleCollection<BlogCategoryLocale> _locales;

        #endregion

         #region Public Constructors

        public BlogCategory( Culture defaultCulture )
        {
            _defaultCulture = defaultCulture;
            _locales = new LocaleCollection<BlogCategoryLocale>(this);
        }

        public BlogCategory()
        {
            _defaultCulture = new Culture();
            _locales = new LocaleCollection<BlogCategoryLocale>( this );
        }

        #endregion

        #region Public Properties

        public static BlogCategory Null
        {
            get { return NullBlogCategory.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public string BlogCategoryID { get { return _blogCategoryID; } set { _blogCategoryID = value; } }
        public string UrlName { get { return _urlName; } set { _urlName = value; } }
        public bool IsEnabled { get { return _isEnabled; } set { _isEnabled = value; } }
        public int SortOrder { get { return _sortOrder; } set { _sortOrder = value; } }
        public Culture DefaultCulture { get { return _defaultCulture; } set { _defaultCulture = value; } }
        public LocaleCollection<BlogCategoryLocale> Locales { get { return _locales; } }

        //------------------------------------------------------------
        // Locale items
        public string Name
        {
            get { return Locales[DefaultCulture].Name; }
            set { Locales.GetNoLoad( DefaultCulture ).Name = value; }
        }
        public string Description
        {
            get { return Locales[DefaultCulture].Description; }
            set { Locales.GetNoLoad( DefaultCulture ).Description = value; }
        }
        public string MetaKeyword
        {
            get { return Locales[DefaultCulture].MetaKeyword; }
            set { Locales.GetNoLoad( DefaultCulture ).MetaKeyword = value; }
        }
        public string MetaDescription
        {
            get { return Locales[DefaultCulture].MetaDescription; }
            set { Locales.GetNoLoad( DefaultCulture ).MetaDescription = value; }
        }

        // End Locale items
        //------------------------------------------------------------

        #endregion

        #region IClonable Members

        public object Clone()
        {
            BlogCategory newObject = (BlogCategory) MemberwiseClone();
            newObject._locales = (LocaleCollection<BlogCategoryLocale>) _locales.Clone();

            return newObject;
        }

        #endregion

        #region ILocaleLoader Members

        public IList<ILocale> GetLocales()
        {
            List<ILocale> result = new List<ILocale>();
            foreach (BlogCategoryLocale locale in DataAccessContext.BlogCategoryRepository.GetLocales( BlogCategoryID ))
                result.Add( locale );

            return result;
        }
        #endregion

        #region Public Methods
        public string GetMetaDescription( Culture culture )
        {
            if (!String.IsNullOrEmpty( Locales[culture].MetaDescription ))
                return Locales[culture].MetaDescription;
            else
                return Locales[culture].Description;
        }

        public string GetMetaKeyword( Culture culture )
        {
            if (!String.IsNullOrEmpty( Locales[culture].MetaKeyword ))
                return Locales[culture].MetaKeyword;
            else
                return Locales[culture].Name;
        }

        #endregion
    }
}
