﻿using System.Collections.Generic;
using System.IO;
using Vevo.Domain.Products;

namespace Vevo.Domain.ImportExport
{
    public class ProductKitGroupItemExporter
    {
        private string convertBoolToCSV( bool value )
        {
            if (value)
                return "Yes";
            else
                return "No";
        }

        private string GenerateHeader()
        {
            return "\"ProductKitGroupID\",\"Sku\",\"Quantity\",\"IsUserDefinedQuantity\",\"IsDefault\"";
        }

        private string GenerateDetail( ProductKitItem item, Culture culture, string storeID )
        {
            string productKitGroupID = item.ProductKitGroupID;
            string sku = DataAccessContext.ProductRepository.GetOne( culture, item.ProductID, storeID ).Sku;
            string quantity = item.Quantity.ToString();
            string isUserDefined = convertBoolToCSV( item.IsUserDefinedQuantity );
            string isDefault = convertBoolToCSV( item.IsDefault );

            return productKitGroupID + "," + sku + "," + quantity + "," + isUserDefined + "," + isDefault;
        }

        public MemoryStream ExportToStream( IList<ProductKitItem> kitItemList, Culture culture, string storeID )
        {
            //Create the return memorystream object that will hold the buffered data.
            MemoryStream returnStream = new MemoryStream();

            //Create a streamwriter to write to the memory stream
            StreamWriter sw = new StreamWriter( returnStream );

            if (kitItemList.Count > 0)
            {
                sw.WriteLine( GenerateHeader() );
                string details;
                foreach (ProductKitItem kitItem in kitItemList)
                {
                    details = GenerateDetail( kitItem, culture, storeID );
                    sw.WriteLine( details );
                }
            }

            //Clean up the stream writer
            sw.Flush();
            //sw.Close();

            return returnStream;
        }
    }
}
