using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using Vevo.Shared.Utilities;

namespace Vevo.Domain.Orders
{
    public class OrderItemExporter
    {
        #region Private

        private string GenerateHeader()
        {
            return "\"OrderItemID\",\"OrderID\",\"ProductID\",\"Quantity\",\"Name\",\"Sku\",\"Model\",\"UnitPrice\"," +
                    "\"SecondaryUnitPrice\",\"Options\",\"GiftRegistryItemID\",\"UploadFile\",\"RecurringID\",\"DownloadCount\"";

        }

        private string GenerateDetail( OrderItem orderItem )
        {
            string orderItemID, orderID, productID, quantity, name, sku, model, unitPrice;
            string secondaryUnitPrice, options, giftRegistryItemID, uploadFile, recurringID, downloadCount;

            orderItemID = orderItem.OrderItemID;
            orderID = orderItem.OrderID;
            productID = orderItem.ProductID;
            quantity = ConvertUtilities.ToString( orderItem.Quantity );
            name = orderItem.Name;
            sku = orderItem.Sku;
            model = orderItem.Model;
            unitPrice = ConvertUtilities.ToString( orderItem.UnitPrice );
            secondaryUnitPrice = String.Empty;
            options = String.Empty;
            giftRegistryItemID = orderItem.GiftRegistryItemID;
            uploadFile = orderItem.UploadFile;
            recurringID = orderItem.RecurringID;
            downloadCount = ConvertUtilities.ToString( orderItem.DownloadCount );

            return orderItemID + "," + orderID + "," + productID + "," + quantity + "," + name + "," +
                sku + "," + model + "," + unitPrice + "," + secondaryUnitPrice + "," + options + "," +
                giftRegistryItemID + "," + uploadFile + "," + recurringID + "," + downloadCount;
        }

        #endregion

        #region Public Methods

        public IList<OrderItem> GetOrderItemList( IList<Order> orderList )
        {
            List<OrderItem> orderItemList = new List<OrderItem>();

            foreach (Order order in orderList)
            {
                foreach (OrderItem orderItem in order.OrderItems)
                {
                    orderItemList.Add( orderItem );
                }
            }

            return orderItemList;
        }

        public MemoryStream ExportToStream( IList<OrderItem> orderItemList )
        {
            //Create the return memorystream object that will hold the buffered data.
            MemoryStream returnStream = new MemoryStream();

            //Create a streamwriter to write to the memory stream
            StreamWriter sw = new StreamWriter( returnStream );

            if (orderItemList.Count > 0)
            {
                sw.WriteLine( GenerateHeader() );
                string details;
                foreach (OrderItem orderItem in orderItemList)
                {
                    details = GenerateDetail( orderItem );
                    sw.WriteLine( details );
                }
            }


            //Clean up the stream writer
            sw.Flush();
            //sw.Close();

            return returnStream;
        }

        #endregion
    }
}
