using System;
using System.Web.Services;
using System.Web.Security;
using log4net;
using Vevo.Domain;
using Vevo.Deluxe.Domain.QuickBooks;
using Vevo.Shared.DataAccess;
using Vevo.Deluxe.Domain;

namespace Vevo.QuickBooks
{
    /// <summary>
    /// Summary description for QBWCServices
    /// </summary>
    [WebService( Namespace = "http://developer.intuit.com/" )]
    [WebServiceBinding( ConformsTo = WsiProfiles.BasicProfile1_1 )]
    public class QBWCServices : WebService, IQBWebConnectorSvcSoap
    {
        #region Private
        private ILog _logger;

        private ILog Logger
        {
            get
            {
                if (_logger == null)
                {
                    _logger = LogManager.GetLogger( typeof( QBWCServices ) );
                }

                return _logger;
            }
        }

        private void LogSeparator()
        {
            Logger.Debug( "\n" );
            Logger.Debug( "--------------------------------" );
        }

        private string GetInvalidTicketMessage( string functionName, string ticket )
        {
            return String.Format( "Invalid Ticket: Function '{0}', Ticket {1}",
                functionName, ticket );
        }

        private bool IsAuthenticateUser( string userName )
        {
            string users = DataAccessContext.Configurations.GetValue( "QBVevoAdminUser" );

            if ( users.Equals( userName ) && Roles.IsUserInRole( userName, "Administrators" ) )
                return true;
            else
                return false;
        }

        private string CreateQBLog()
        {
            QuickBooksLog quickBooksLog = new QuickBooksLog();
            quickBooksLog.QBExportDate = DateTime.Now;

            quickBooksLog = DataAccessContextDeluxe.QuickBooksLogRepository.Save( quickBooksLog );

            return quickBooksLog.QBLogID;
        }
        #endregion


        #region Contructors
        public QBWCServices()
        {
            
        }
        #endregion


        #region Methods
        /// <remarks/>
        [WebMethod]
        public string[] authenticate( string strUserName, string strPassword )
        {
            string qbLogID = String.Empty;
            string autheticateMessage = String.Empty; 
            
            LogSeparator();

            Logger.DebugFormat(
                "authenticate: strUserName = {0}, strPassword = {1}",
                strUserName, strPassword );

            //******
            //Authentication here
            //******            
            bool success = IsAuthenticateUser( strUserName ) && Membership.ValidateUser( strUserName, strPassword ) && (KeyUtilities.IsDeluxeLicense( DataAccessHelper.DomainRegistrationkey, DataAccessHelper.DomainName ));

            if (success)
            {
                qbLogID = CreateQBLog();

                Logger.DebugFormat( "User authenticated" );
            }
            else
            {
                autheticateMessage = "nvu";

                Logger.DebugFormat( "User not authenticated" );
            }

            string ticket = QBWCSessionPool.CreateSession( qbLogID );
            
            return new string[] { ticket, autheticateMessage};
        }

        /// <remarks/>
        [WebMethod]
        public string sendRequestXML(
            string ticket,
            string strHCPResponse,
            string strCompanyFileName,
            string qbXMLCountry,
            int qbXMLMajorVers,
            int qbXMLMinorVers )
        {
            Logger.DebugFormat(
                "sendRequestXML: ticket = {0}, strHCPResponse = '{1}', " +
                "strCompanyFileName = {2}, qbXMLCountry = {3}, qbXMLMajorVers = {4}, qbXMLMinorVers = {5}",
                ticket, strHCPResponse, strCompanyFileName,
                qbXMLCountry, qbXMLMajorVers, qbXMLMinorVers );

            QBWCSession qbwcsession = QBWCSessionPool.GetSession( ticket );
            if (qbwcsession == null)
            {
                qbwcsession.LastErrorMessage = GetInvalidTicketMessage( "sendRequestXML", ticket );
                return String.Empty;
            }

            try
            {
                string xml = qbwcsession.OnSendRequestXml();

                Logger.Debug( "sendRequestXML: XML to send ---" );
                Logger.Debug( xml );

                return xml;
            }
            catch (Exception ex)
            {
                qbwcsession.LastErrorMessage = ex.Message;

                Logger.ErrorFormat( "sendRequestXML: Error '{0}', Stack {1}",
                    ex.Message, ex.StackTrace );

                return String.Empty;
            }
        }

        /// <remarks/>
        [WebMethod]
        public int receiveResponseXML(
            string ticket,
            string response,
            string hresult,
            string message )
        {
            Logger.DebugFormat(
                "receiveResponseXML: ticket = {0}, response = '{1}', hresult = {2}, message = '{3}'",
                ticket, response, hresult, message );

            QBWCSession qbwcsession = QBWCSessionPool.GetSession( ticket );
            if (qbwcsession == null)
            {
                qbwcsession.LastErrorMessage = GetInvalidTicketMessage( "receiveResponseXML", ticket );
                return -1;
            }

            try
            {
                Logger.DebugFormat( "receiveResponseXML: '{0}'", response );

                return qbwcsession.OnReceiveResponseXml( response );
            }
            catch (Exception ex)
            {
                qbwcsession.LastErrorMessage = ex.Message;

                Logger.ErrorFormat( "receiveResponseXML: Error '{0}', Stack {1}",
                    ex.Message, ex.StackTrace );

                return -1;
            }
        }

        /// <remarks/>
        [WebMethod]
        public string connectionError(
            string ticket,
            string hresult,
            string message )
        {
            Logger.ErrorFormat( "Connection Error " );

            return null;
        }

        /// <remarks/>
        [WebMethod]
        public string getLastError( string ticket )
        {
            QBWCSession session = QBWCSessionPool.GetSession( ticket );
            if (session == null)
            {
                return GetInvalidTicketMessage( "sendRequestXML", ticket );
            }

            return session.LastErrorMessage;
        }

        /// <remarks/>
        [WebMethod]
        public string closeConnection( string ticket )
        {
            QBWCSessionPool.DeleteSession( ticket );
            Logger.ErrorFormat( "Close Connection " );
            return "OK";
        }
        #endregion

    }

}
