using System;
using System.Collections.Generic;
using Vevo.Domain.Products;
using Vevo.Domain;
using Vevo.QuickBooks.Qbxml70;

namespace Vevo.QuickBooks.States
{
    /// <summary>
    /// Summary description for ProductVerifyResponseState
    /// </summary>
    public class ProductVerifyResponseState : QBWCState
    {
        private void MoveToNextState()
        {
            QBWCSession.CurrentState = new ProductQueryRequestState( QBWCSession );
        }

        private void UpdateData( string existList )
        {
            string cultureID = DataAccessContext.CultureRepository.GetIDByName(
                DataAccessContext.Configurations.GetValue( "DefaultWebsiteLanguage" ) );
            Culture culture = DataAccessContext.CultureRepository.GetOne( cultureID );

            string storeID = getStoreID();
            string rootCategoryID = DataAccessContext.Configurations.GetValue( "0", "RootCategory", storeID );

            IList<Product> table = DataAccessContext.ProductRepository.GetByIsQBExported( 
                culture, true, rootCategoryID, storeID, existList );

            foreach (Product product in table)
            {
                DataAccessContext.ProductRepository.SetDefaultQBData( product.QBListID );
            }
        }

        private string getStoreID()
        {
            return DataAccessContext.Configurations.GetValue( "QBSelectStoreExport" );
        }

        private void ProcessResponse( string response )
        {
            QBXMLMsgsRs qbXmlMsgsRs = CreateResponse( response );
            string existList = String.Empty;
            for (int i = 0; i < qbXmlMsgsRs.Items.Length; i++)
            {
                ItemNonInventoryQueryRsType result = (ItemNonInventoryQueryRsType) qbXmlMsgsRs.Items[i];

                if (result.statusCode.ToString() == "0")
                {
                    if (String.IsNullOrEmpty( existList ))
                        existList = "'" + result.ItemNonInventoryRet[0].ListID + "'";
                    else
                        existList += ",'" + result.ItemNonInventoryRet[0].ListID + "'";
                }
            }

            UpdateData( existList );
        }

        public ProductVerifyResponseState( QBWCSession session )
            : base( session )
        {
        }

        public override int OnReceiveResponseXml( string responseXml )
        {
            ProcessResponse( responseXml );

            MoveToNextState();

            return 40;
        }
    }
}