using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Vevo.Shared.DataAccess;
using Vevo.Shared.DataAccess.Implementation;

namespace Vevo.Reports
{
    public class SearchReportBuilder
    {
        private string GetTopNumber( string numberOfResult )
        {
            if (numberOfResult == "All")
            {
                return "";
            }
            else
            {
                return "TOP " + numberOfResult;
            }
        }

        private DataTable GetSearchReport(
            string numberOfResult,
            string sortBy,
            DateTime startSearchDate,
            DateTime endSearchDate,
            PeriodType period )
        {
            ArrayList parameters = new ArrayList();
            string from, to;
            if (period == PeriodType.Last24Hours)
            {
                from = DateFilterHelper.CreateFromDateFor24HoursNoAnd(
                    startSearchDate, parameters, "from", "SearchDate" );
                to = DateFilterHelper.CreateToDateFor24HoursWithAnd(
                    endSearchDate, parameters, "to", "SearchDate" );
            }
            else
            {
                from = DateFilterHelper.CreateFromDateNoAnd(
                    startSearchDate, parameters, "from", "SearchDate" );
                to = DateFilterHelper.CreateToDateWithAnd(
                    endSearchDate, parameters, "to", "SearchDate" );
            }

            string sort = "";
            if (numberOfResult != "All")
            {
                sort = "ORDER BY COUNT(Keyword) DESC";
            }

            string script = "SELECT SearchLog.Keyword, " +
                "[Found], NotFound, Total, (" +
                DbImplementation.Sql.CreateDivideFucntion( "[Found]", "Total" ) + "*100) as Percentage " +
                "FROM SearchLog " +
                "INNER JOIN( " +
                "SELECT " + GetTopNumber( numberOfResult ) + " (COUNT(Keyword)) as Total, " +
                "Keyword, " +
                DbImplementation.Sql.CreateConvertBoolToSumInt( "IsFound" ) + " as [Found], " +
                "(COUNT(Keyword) - " + DbImplementation.Sql.CreateConvertBoolToSumInt( "IsFound" ) +
                ") as NotFound " +
                "FROM SearchLog " +
                "WHERE " +
                from +
                to +
                "GROUP BY Keyword " +
                sort +
                ") S1 on " +
                "SearchLog.Keyword = S1.Keyword " +
                "GROUP BY SearchLog.Keyword, " +
                "[Found], NotFound, Total ";

            DataTable SearchReportTable = DataAccess.ExecuteSelect( script,
                DataAccess.ConvertArrayListToDbParameters( parameters ) );

            if (numberOfResult != "All")
            {
                int numresult = Convert.ToInt32( numberOfResult );

                if (SearchReportTable.Rows.Count > numresult)
                {
                    int numberOfRemove = SearchReportTable.Rows.Count - numresult;
                    for (int i = 0; i < numberOfRemove; i++)
                        SearchReportTable.Rows.RemoveAt( numresult );
                }
            }

            SearchReportTable.DefaultView.Sort = sortBy;

            return SearchReportTable;
        }

        private DataTable GetSearchReport(
            string numberOfResult,
            string sortBy,
            DateTime startOrderDate,
            DateTime endOrderDate,
            int startIndex,
            int endIndex,
            PeriodType period,
            out int howManyItems )
        {
            DataTable full = GetSearchReport( numberOfResult, sortBy, startOrderDate, endOrderDate, period );

            howManyItems = full.Rows.Count;

            DataColumn[] keys = new DataColumn[] { full.Columns["Product.ProductID"] };
            full.PrimaryKey = keys;

            DataView view = new DataView( full );
            view.Sort = sortBy;

            DataTable sortedTable = view.ToTable();

            return DataAccess.CopyTableRows( sortedTable, startIndex, endIndex );
        }

        public DataTable GetSearchReportData(
            string sortBy,
            string numDisplay,
            PeriodType period,
            DateTime startSearchDate,
            DateTime endSearchDate )
        {
            DataTable table;
            table = GetSearchReport(
                numDisplay,
                sortBy,
                startSearchDate,
                endSearchDate,
                period );
            return table;
        }

        public DataTable GetSearchReportData(
            string sortBy,
            string numDisplay,
            PeriodType period,
            DateTime startSearchDate,
            DateTime endSearchDate,
            int startIndex,
            int endIndex,
            out int totalItems )
        {
            DataTable table;
            table = GetSearchReport(
                numDisplay,
                sortBy,
                startSearchDate,
                endSearchDate,
                startIndex,
                endIndex,
                period,
                out totalItems );
            return table;
        }
    }
}
