﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ServiceModel;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.WebAppLib;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain;
using System.Data;
using Vevo.Domain.Marketing;
using Vevo.Base.Domain;
using Vevo.Deluxe.Domain.Marketing;
using Vevo.Deluxe.Domain;

namespace Vevo.WebServices.CommissionPendings
{
    public class CommissionPendingService : ICommissionPendingService
    {
        private CommissionPendingConstraints ConvertCommissionPendingToConstraints( AffiliateOrder commissionPending )
        {
            CommissionPendingConstraints constraints = new CommissionPendingConstraints();
            constraints.AffiliateCode = commissionPending.AffiliateCode;
            constraints.AffiliateOrderID = commissionPending.AffiliateOrderID;
            constraints.AffiliatePaymentID = commissionPending.AffiliatePaymentID;
            constraints.Commission = commissionPending.Commission;
            constraints.OrderID = commissionPending.OrderID;
            constraints.PaymentStatus = commissionPending.PaymentStatus;
            constraints.Pending = commissionPending.Pending;

            return constraints;
        }

        public CommissionPendingListResponseMessage ListCommissionPendings(CommissionPendingListRequestMessage ListMessage )
        {
            CommissionPendingListResponseMessage responseMessage = new CommissionPendingListResponseMessage();
            if ( WcfSessionPool.GetSession( ListMessage.Ticket ) == null )
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter( ListMessage.SearchFilter );
                int commissionPendingCount = 0;
                IList<AffiliateOrder> commissionPending_result = DataAccessContextDeluxe.AffiliateOrderRepository.SearchAffiliateOrder(
                    ListMessage.AffiliateCode, "AffiliateOrderID", searchFilter, ListMessage.ExtraFilter,
                    ListMessage.SearchFilter.StartIndex, ListMessage.SearchFilter.EndIndex, out commissionPendingCount );
                responseMessage.CommissionPendings = new List<CommissionPendingConstraints>();
                foreach ( AffiliateOrder commissionPending in commissionPending_result )
                {
                    responseMessage.CommissionPendings.Add( ConvertCommissionPendingToConstraints( commissionPending ) );
                }
            }
            catch ( Exception e )
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get commission pendings from repository";
            }

            return responseMessage;
        }
    }
}
