using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using System.Web;
using Vevo.DataAccessLib;
using Vevo.DataAccessLib.Cart;
using Vevo.Domain;
using Vevo.WebAppLib;

namespace Vevo.WebUI.DataAccessCache
{
    public interface IAdminMenuPermissionAccessCache
    {
        DataTable GetAllByAdminID( string adminID );
    }


    /// <summary>
    /// Summary description for AdminMenuPermissionAccessCache
    /// </summary>
    public static class AdminMenuPermissionAccessCache
    {
        private static CachedAdminMenuPermissionAccessObject _cachedObject = 
            new CachedAdminMenuPermissionAccessObject();
        private static NonCachedAdminMenuPermissionAccessObject _nonCachedObject = 
            new NonCachedAdminMenuPermissionAccessObject();


        public static IAdminMenuPermissionAccessCache Instance
        {
            get
            {
                if (DataAccessContext.Configurations.GetBoolValueNoThrow( "AdminCachingEnabled" ))
                    return _cachedObject;
                else
                    return _nonCachedObject;
            }
        }

        public static void ClearCache()
        {
            _cachedObject.ClearCache();
        }



        //----------------------------------------------------------------------------------
        // CachedAdminMenuPermissionAccessObject
        //----------------------------------------------------------------------------------

        private class CachedAdminMenuPermissionAccessObject : BaseDataAccessCache, IAdminMenuPermissionAccessCache
        {
            public CachedAdminMenuPermissionAccessObject()
                : base( "AdminMenuPermissionAccess" )
            {
            }

            public DataTable GetAllByAdminID( string adminID )
            {
                return (DataTable) CachedMethod(
                    "GetAllByAdminID",
                    AdminMenuPermissionAccess.GetAllByAdminID,
                    adminID );
            }
        }

        //----------------------------------------------------------------------------------
        // NonCachedAdminMenuPermissionAccessObject
        //----------------------------------------------------------------------------------

        private class NonCachedAdminMenuPermissionAccessObject : IAdminMenuPermissionAccessCache
        {
            public DataTable GetAllByAdminID( string adminID )
            {
                return AdminMenuPermissionAccess.GetAllByAdminID( adminID );
            }
        }
    }
}
